@@ -1,19 +1,18 @@
 package Net::IPAM::Block;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use 5.10.0;
 use strict;
 use warnings;
 use utf8;
 
-use Carp qw(croak);
-use List::Util qw(any all);
-use Scalar::Util qw(blessed);
-###
-use namespace::clean;
+use Carp            ();
+use List::Util      ();
+use Scalar::Util    ();
+use Net::IPAM::IP   ();
+use Net::IPAM::Util ();
 
-use Net::IPAM::IP;
 use overload
   '""'     => sub { shift->to_string },
   bool     => sub { 1 },
@@ -96,7 +95,7 @@ Returns undef on illegal input.
 =cut
 
 sub new {
-  croak 'wrong method call' unless defined $_[1];
+  Carp::croak 'missing argument' unless defined $_[1];
 
   my $self  = bless( {}, $_[0] );
   my $input = $_[1];
@@ -191,7 +190,7 @@ sub _fromAddr {
 sub _fromIP {
   my ( $self, $base ) = @_;
 
-  return unless blessed($base) && $base->isa('Net::IPAM::IP');
+  return unless Scalar::Util::blessed($base) && $base->isa('Net::IPAM::IP');
 
   my $bits = 32;
   $bits = 128 if $base->version == 6;
@@ -300,7 +299,7 @@ sub cidrsplit {
   my $last1_n = _make_last_n( $base_n, $next_mask_n );
 
   # make next base by incrementing last
-  my $base2_n = Net::IPAM::IP::incr_n($last1_n);
+  my $base2_n = Net::IPAM::Util::incr_n($last1_n);
   my $last2_n = _make_last_n( $base2_n, $next_mask_n );
 
   # make new cidr blocks
@@ -394,7 +393,7 @@ sub to_cidrs {
     }
 
     #  move the $cursor one behind last
-    $cursor_n = Net::IPAM::IP::incr_n($last_n) // die 'OVERFLOW: logic error,';
+    $cursor_n = Net::IPAM::Util::incr_n($last_n) // die 'OVERFLOW: logic error,';
   }
 
   return wantarray ? @result : [@result];
@@ -584,7 +583,7 @@ cmp() returns -1, 0, +1:
 =cut
 
 sub cmp {
-  croak "wrong or missing arg" unless ref $_[1] && $_[1]->isa(__PACKAGE__);
+  Carp::croak "wrong or missing arg" unless ref $_[1] && $_[1]->isa(__PACKAGE__);
 
   return -1 if $_[0]->{base}->cmp( $_[1]->{base} ) < 0;
   return 1  if $_[0]->{base}->cmp( $_[1]->{base} ) > 0;
@@ -614,7 +613,7 @@ Returns true if the blocks are disjunct
 =cut
 
 sub is_disjunct_with {
-  croak "wrong or missing arg" unless ref $_[1] && $_[1]->isa(__PACKAGE__);
+  Carp::croak "wrong or missing arg" unless ref $_[1] && $_[1]->isa(__PACKAGE__);
 
   #  a       |----------|
   #  b |---|
@@ -648,7 +647,7 @@ Returns true if the blocks overlap.
 =cut
 
 sub overlaps_with {
-  croak "wrong or missing arg" unless ref $_[1] && $_[1]->isa(__PACKAGE__);
+  Carp::croak "wrong or missing arg" unless ref $_[1] && $_[1]->isa(__PACKAGE__);
 
   # false if a == b
   return if $_[0]->cmp( $_[1] ) == 0;
@@ -689,7 +688,7 @@ sub contains {
     return _contains_ip(@_)    if $_[1]->isa('Net::IPAM::IP');
     return _contains_block(@_) if $_[1]->isa('Net::IPAM::Block');
   }
-  croak 'wrong argument,';
+  Carp::croak 'wrong argument,';
 }
 
 # a.base <= b && a.last >= b
@@ -741,13 +740,13 @@ sub find_free_cidrs {
     my $this = shift @candidates;
 
     # mark it as free, if this block is disjunct with ALL inner blocks
-    if ( all { $this->is_disjunct_with($_) } @inner ) {
+    if ( List::Util::all { $this->is_disjunct_with($_) } @inner ) {
       push @free, $this;
       next;
     }
 
     # skip if this block is already contained in ANY inner block or equal with
-    if ( any { $_->contains($this) || $_->cmp($this) == 0 } @inner ) {
+    if ( List::Util::any { $_->contains($this) || $_->cmp($this) == 0 } @inner ) {
       next;
     }
 
@@ -755,7 +754,7 @@ sub find_free_cidrs {
     push @candidates, $this->cidrsplit;
 
     # limit cpu and memory
-    croak("too many CIDRs generated,") if @candidates > $MaxCIDRSplit;
+    Carp::croak("too many CIDRs generated,") if @candidates > $MaxCIDRSplit;
   }
 
   @free = sort { $a->cmp($b) } @free;
@@ -848,10 +847,10 @@ sub _get_mask_ip {
 
   # version base != version last
   my $version = $base_ip->version;
-  croak 'version mismatch,' if $version != $last_ip->version;
+  Carp::croak 'version mismatch,' if $version != $last_ip->version;
 
   # base > last?
-  croak 'base > last,' if $base_ip->cmp($last_ip) > 0;
+  Carp::croak 'base > last,' if $base_ip->cmp($last_ip) > 0;
 
   my $bits = 32;
   $bits = 128 if $version == 6;
